@@ -17,9 +17,8 @@ def expected_return(token, ticker, date):
     response = requests.get(url).text
     return round(float(response),2)
 
-def kelly_criterion(token, ticker, date): 
-    url = "https://spawnerapi.com/kelly-criterion/" + ticker + "/" + date + "/" + token
+def kelly_criterion(token, ticker): 
+    url = "https://spawnerapi.com/kelly-criterion/" + ticker + "/" + token
     response = requests.get(url).text
     return round(float(response),2)
 
-
